pub fn is_object_storage(object_store: &ObjectStore) -> boolExpand description
Returns true if the object store is not backed by local filesystem.
pub fn is_object_storage(object_store: &ObjectStore) -> boolReturns true if the object store is not backed by local filesystem.